var namespaces_dup =
[
    [ "flecs", null, [
      [ "_", "namespaceflecs_1_1__.html", "namespaceflecs_1_1__" ],
      [ "actual_type", "structflecs_1_1actual__type.html", null ],
      [ "actual_type< T, if_not_t< is_pair< T >::value > >", "structflecs_1_1actual__type_3_01T_00_01if__not__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html", null ],
      [ "actual_type< T, if_t< is_pair< T >::value > >", "structflecs_1_1actual__type_3_01T_00_01if__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html", null ],
      [ "alert", "structflecs_1_1alert.html", "structflecs_1_1alert" ],
      [ "alert_builder", "structflecs_1_1alert__builder.html", null ],
      [ "alert_builder_i", "structflecs_1_1alert__builder__i.html", "structflecs_1_1alert__builder__i" ],
      [ "alerts", "structflecs_1_1alerts.html", "structflecs_1_1alerts" ],
      [ "app_builder", "structflecs_1_1app__builder.html", null ],
      [ "arity", "structflecs_1_1arity.html", null ],
      [ "array", "structflecs_1_1array.html", null ],
      [ "array< T, Size, enable_if_t< Size !=0 > >", "structflecs_1_1array_3_01T_00_01Size_00_01enable__if__t_3_01Size_01_9_0a0_01_4_01_4.html", null ],
      [ "array< T, Size, enable_if_t< Size==0 > >", "structflecs_1_1array_3_01T_00_01Size_00_01enable__if__t_3_01Size_0a_0a0_01_4_01_4.html", null ],
      [ "array_iterator", "structflecs_1_1array__iterator.html", null ],
      [ "base_arg_type", "structflecs_1_1base__arg__type.html", null ],
      [ "base_type", "structflecs_1_1base__type.html", null ],
      [ "bitmask", "structflecs_1_1bitmask.html", null ],
      [ "component", "structflecs_1_1component.html", "structflecs_1_1component" ],
      [ "cursor", "structflecs_1_1cursor.html", "structflecs_1_1cursor" ],
      [ "entity", "structflecs_1_1entity.html", "structflecs_1_1entity" ],
      [ "entity_builder", "structflecs_1_1entity__builder.html", "structflecs_1_1entity__builder" ],
      [ "entity_view", "structflecs_1_1entity__view.html", "structflecs_1_1entity__view" ],
      [ "enum_data", "structflecs_1_1enum__data.html", "structflecs_1_1enum__data" ],
      [ "enum_last", "structflecs_1_1enum__last.html", null ],
      [ "event_builder", "structflecs_1_1event__builder.html", null ],
      [ "event_builder_base", "structflecs_1_1event__builder__base.html", "structflecs_1_1event__builder__base" ],
      [ "event_builder_typed", "structflecs_1_1event__builder__typed.html", null ],
      [ "field", "structflecs_1_1field.html", "structflecs_1_1field" ],
      [ "first_arg", "structflecs_1_1first__arg.html", null ],
      [ "first_arg_impl", "structflecs_1_1first__arg__impl.html", null ],
      [ "first_arg_impl< Func, _::arg_list< T, Args ... > >", "structflecs_1_1first__arg__impl_3_01Func_00_01___1_1arg__list_3_01T_00_01Args_01_8_8_8_01_4_01_4.html", null ],
      [ "id", "structflecs_1_1id.html", "structflecs_1_1id" ],
      [ "is_actual", "structflecs_1_1is__actual.html", null ],
      [ "is_callable", "structflecs_1_1is__callable.html", null ],
      [ "is_flecs_constructible", "structflecs_1_1is__flecs__constructible.html", null ],
      [ "is_pair", "structflecs_1_1is__pair.html", null ],
      [ "is_same", "classflecs_1_1is__same.html", null ],
      [ "iter", "structflecs_1_1iter.html", "structflecs_1_1iter" ],
      [ "iter_iterable", "structflecs_1_1iter__iterable.html", "structflecs_1_1iter__iterable" ],
      [ "iterable", "structflecs_1_1iterable.html", "structflecs_1_1iterable" ],
      [ "metric_builder", "structflecs_1_1metric__builder.html", null ],
      [ "metrics", "structflecs_1_1metrics.html", "structflecs_1_1metrics" ],
      [ "observer", "structflecs_1_1observer.html", "structflecs_1_1observer" ],
      [ "observer_builder", "structflecs_1_1observer__builder.html", null ],
      [ "observer_builder_i", "structflecs_1_1observer__builder__i.html", "structflecs_1_1observer__builder__i" ],
      [ "opaque", "structflecs_1_1opaque.html", "structflecs_1_1opaque" ],
      [ "page_iterable", "structflecs_1_1page__iterable.html", null ],
      [ "pair", "structflecs_1_1pair.html", null ],
      [ "pipeline", "structflecs_1_1pipeline.html", null ],
      [ "pipeline_builder", "structflecs_1_1pipeline__builder.html", null ],
      [ "pipeline_builder_i", "structflecs_1_1pipeline__builder__i.html", null ],
      [ "query", "structflecs_1_1query.html", null ],
      [ "query_base", "structflecs_1_1query__base.html", "structflecs_1_1query__base" ],
      [ "query_builder", "structflecs_1_1query__builder.html", null ],
      [ "query_builder_i", "structflecs_1_1query__builder__i.html", "structflecs_1_1query__builder__i" ],
      [ "ref", "structflecs_1_1ref.html", null ],
      [ "scoped_world", "structflecs_1_1scoped__world.html", null ],
      [ "script_builder", "structflecs_1_1script__builder.html", null ],
      [ "second_arg", "structflecs_1_1second__arg.html", null ],
      [ "second_arg_impl", "structflecs_1_1second__arg__impl.html", null ],
      [ "second_arg_impl< Func, _::arg_list< First, T, Args ... > >", "structflecs_1_1second__arg__impl_3_01Func_00_01___1_1arg__list_3_01First_00_01T_00_01Args_01_8_8_8_01_4_01_4.html", null ],
      [ "stats", "structflecs_1_1stats.html", null ],
      [ "string", "structflecs_1_1string.html", null ],
      [ "string_view", "structflecs_1_1string__view.html", null ],
      [ "stringstream", "structflecs_1_1stringstream.html", null ],
      [ "system", "structflecs_1_1system.html", "structflecs_1_1system" ],
      [ "system_builder", "structflecs_1_1system__builder.html", null ],
      [ "system_builder_i", "structflecs_1_1system__builder__i.html", "structflecs_1_1system__builder__i" ],
      [ "system_runner_fluent", "structflecs_1_1system__runner__fluent.html", null ],
      [ "table", "structflecs_1_1table.html", "structflecs_1_1table" ],
      [ "table_range", "structflecs_1_1table__range.html", "structflecs_1_1table__range" ],
      [ "term", "structflecs_1_1term.html", null ],
      [ "term_builder_i", "structflecs_1_1term__builder__i.html", "structflecs_1_1term__builder__i" ],
      [ "term_ref_builder_i", "structflecs_1_1term__ref__builder__i.html", null ],
      [ "timer", "structflecs_1_1timer.html", "structflecs_1_1timer" ],
      [ "type", "structflecs_1_1type.html", "structflecs_1_1type" ],
      [ "units", "structflecs_1_1units.html", null ],
      [ "untyped_component", "structflecs_1_1untyped__component.html", "structflecs_1_1untyped__component" ],
      [ "untyped_field", "structflecs_1_1untyped__field.html", "structflecs_1_1untyped__field" ],
      [ "untyped_ref", "structflecs_1_1untyped__ref.html", "structflecs_1_1untyped__ref" ],
      [ "worker_iterable", "structflecs_1_1worker__iterable.html", null ],
      [ "world", "structflecs_1_1world.html", "structflecs_1_1world" ],
      [ "pair_first_t", "group__cpp__pair__type.html#gafbe761180d0c10d50a1ddb50f6f66eeb", null ],
      [ "pair_second_t", "group__cpp__pair__type.html#ga8c664b7fef1bb65d68e3155a0c908e23", null ],
      [ "pair_type_t", "group__cpp__pair__type.html#ga301d90dff367ff0b7974bb189b7ea1b7", null ],
      [ "PipelineStats", "group__cpp__addons__stats.html#ga9fc70b88cfdeb2da1821fd783eadb57f", null ],
      [ "serialize", "group__cpp__addons__meta.html#ga987426ea7bc2a0aee1850f77c2512888", null ],
      [ "serialize_element", "group__cpp__addons__meta.html#ga3dc1316ac22c97276ffac7060bda16c0", null ],
      [ "serialize_member", "group__cpp__addons__meta.html#gaabc6d5e90f896b1e5f18293a65696fe2", null ],
      [ "serialize_t", "group__cpp__addons__meta.html#gacd2ebeff1d616dd3fe4da8cf655d0ee3", null ],
      [ "serializer", "group__cpp__addons__meta.html#ga35bfe812608b4c02dd1058e71834c974", null ],
      [ "WorldStats", "group__cpp__addons__stats.html#gabb3f9a804e3a4ec5ea1f4ccf48a1f850", null ],
      [ "WorldSummary", "group__cpp__addons__stats.html#ga283e818af6cad018a0b351ef09ca81dc", null ],
      [ "alert", "structflecs_1_1world.html#ga764b816641a41ca927b8cef7f65b07c9", null ],
      [ "alert_count", "structflecs_1_1entity__view.html#gaf25d5bcded81553d04a0ff462ac6a05e", null ],
      [ "app", "structflecs_1_1world.html#ga7f3cd8d628870606cc87ac863b318a30", null ],
      [ "array", "group__cpp__addons__meta.html#ga83a26164619fc68d6c5facd8b6da2671", null ],
      [ "array", "structflecs_1_1world.html#a290dbe18df4d2739f6e3412470f7e421", null ],
      [ "array", "structflecs_1_1world.html#a54a7c8f1b846be215f0fc2d86298603e", null ],
      [ "bit", "group__cpp__addons__meta.html#gab0eec710bc70c33fb74f4285a568a9f9", null ],
      [ "component", "structflecs_1_1world.html#gae215acdf24d5c8edcfc56c2c003e58f2", null ],
      [ "component", "structflecs_1_1world.html#gadf19fec48c5a4b372b9858eb5e1b6bd3", null ],
      [ "constant", "group__cpp__addons__meta.html#ga69e3ff4b179e3b0b464a9f9d72efa772", null ],
      [ "cursor", "structflecs_1_1world.html#ga7801bddc835d400dc71c6261f64fba2b", null ],
      [ "cursor", "structflecs_1_1world.html#af14e2f21de0df9ac42c914b5bf942b8b", null ],
      [ "doc_brief", "structflecs_1_1entity__view.html#gabf672e81afeddec4a4e2c0f8250ff021", null ],
      [ "doc_color", "structflecs_1_1entity__view.html#gac9ee07df2042efd85259a7cf2c4e55f6", null ],
      [ "doc_detail", "structflecs_1_1entity__view.html#gaad57d5f8523631450f0e3ea083fb0d35", null ],
      [ "doc_link", "structflecs_1_1entity__view.html#gaa537a0f49dbd7c563900f2480f85d6a0", null ],
      [ "doc_name", "structflecs_1_1entity__view.html#ga53dd532bce312cc69414e44c4cb9f938", null ],
      [ "doc_uuid", "structflecs_1_1entity__view.html#gaa9f623f19cb2338d558dc5270fc4926e", null ],
      [ "each", "structflecs_1_1world.html#aa0c30cbd4444e54dfa0258a87fd9b5a0", null ],
      [ "each", "structflecs_1_1world.html#a6eadaf81c342aac9d72edda33071a880", null ],
      [ "each", "structflecs_1_1world.html#ab92814d4a48f2e7b25f9b9dec2059f43", null ],
      [ "emit", "structflecs_1_1entity__view.html#a5dbe98d0b92a17ef92636d9fd1f71bf1", null ],
      [ "emit", "structflecs_1_1entity__view.html#af5215e7570046d039308366041644e94", null ],
      [ "emit", "structflecs_1_1entity__view.html#aa273be7c42fc44329c66ea26482ac08e", null ],
      [ "emit", "structflecs_1_1entity__view.html#a0eb8777cbca789b104bb4a26bcd8617c", null ],
      [ "enqueue", "structflecs_1_1entity__view.html#a3d29e383da488d87cfd07f88d8258efd", null ],
      [ "enqueue", "structflecs_1_1entity__view.html#aa5e7d1e6276b93de6590e5671ea42155", null ],
      [ "enqueue", "structflecs_1_1entity__view.html#abb4aa6711a182d00cf45f5329f0339d5", null ],
      [ "enqueue", "structflecs_1_1entity__view.html#a6e4fb24de96dae91124d0c1b3ad0ab33", null ],
      [ "entity", "structflecs_1_1world.html#ga544d341cf586c8af5915f6198d782601", null ],
      [ "entity", "structflecs_1_1world.html#ga516bc5813331e8580f5e105a1349c672", null ],
      [ "entity", "structflecs_1_1world.html#ga509a10bad742e72e1acb3aa0967203c1", null ],
      [ "enum_type", "enum_8hpp.html#ad5172aa1fa3ad4e6d12f4fa522ad4ee5", null ],
      [ "error_range", "group__cpp__addons__meta.html#gaf49405e273bee2ffa0eebb5b3f2f3644", null ],
      [ "event", "structflecs_1_1world.html#ga6c82536f26596e4b777316a21db2ead5", null ],
      [ "event", "structflecs_1_1world.html#ga9f337980a11cd7ae5a73f19c36a47261", null ],
      [ "from_json", "structflecs_1_1entity.html#ga47edfb42247b4e13c3c1c07658be724e", null ],
      [ "from_json", "structflecs_1_1world.html#ga356c77cce822897385366087ed9cae27", null ],
      [ "from_json", "structflecs_1_1world.html#gae2f3a2131e31ef276a42e4d2acd9550a", null ],
      [ "from_json", "structflecs_1_1world.html#gae93eb041a7e3aaef47727d87340f1615", null ],
      [ "from_json_file", "structflecs_1_1world.html#ga23deed85c4e81e096cf8055f7f303cdd", null ],
      [ "get_generation", "world_8hpp.html#a5951af83ac3c6bfda3c10d66fc813453", null ],
      [ "get_pipeline", "structflecs_1_1world.html#a43a0b5b1c160391ccde762a93fa5b3e0", null ],
      [ "get_threads", "structflecs_1_1world.html#a8740b321010aef5c4b73f5f340c680d7", null ],
      [ "id", "structflecs_1_1world.html#aba45bfece31adf0f704ba364d8488c4f", null ],
      [ "id", "structflecs_1_1world.html#abf17f092f477dcc50efc6c9f082d1fad", null ],
      [ "id", "structflecs_1_1world.html#ga74c9840d657c57410cebc5c0fe62903c", null ],
      [ "import", "structflecs_1_1world.html#a30a3e86d6ec3672bc1056dd9b143f9e2", null ],
      [ "interval", "structflecs_1_1system.html#a348b5352a9b2dc459d65bccd322ad1f0", null ],
      [ "interval", "structflecs_1_1system.html#ga34a1a0b44ceace9c28e66ab008d9a97f", null ],
      [ "member", "group__cpp__addons__meta.html#gad3e2eea6ea2be79ca62b92998b62ce07", null ],
      [ "member", "group__cpp__addons__meta.html#gadd5248abcf5015b6e743b226e9ae9097", null ],
      [ "member", "group__cpp__addons__meta.html#gaf19a7d2a71849b9adf2049083809d950", null ],
      [ "member", "group__cpp__addons__meta.html#ga13f4322cddb125f676dade62bdc41ed7", null ],
      [ "member", "group__cpp__addons__meta.html#ga1f1110665e3ab71a58f08ac6fcc0430f", null ],
      [ "member", "group__cpp__addons__meta.html#ga29a5211857f86f17000556ab31ae2afd", null ],
      [ "member", "group__cpp__addons__meta.html#ga77d00535e0aebd71ccafc92d29883dc6", null ],
      [ "member", "group__cpp__addons__meta.html#gad8b0f60b189fceeaf1bd435935945975", null ],
      [ "member", "group__cpp__addons__meta.html#ga6dcc60d7bcfd820d4e0e6ebc8476818f", null ],
      [ "member", "group__cpp__addons__meta.html#ga2c426e74053c6fcda37c20d0a13c2aa1", null ],
      [ "member", "group__cpp__addons__meta.html#ga38ba92b2cb86f06542229069b62a3411", null ],
      [ "member", "group__cpp__addons__meta.html#ga22af278fbce063ba13b314ccacfbba10", null ],
      [ "member", "group__cpp__addons__meta.html#ga5e43f64d820a27818a9b46514a1e3333", null ],
      [ "metric", "group__cpp__addons__metrics.html#gae510f6152ca2e1ed8224a679e944986e", null ],
      [ "metric", "structflecs_1_1world.html#ga3ad069707daed3ddabb4e5a13ac3b4d4", null ],
      [ "module", "structflecs_1_1world.html#gac9a0f511976962585bd5e53451b21b71", null ],
      [ "observe", "structflecs_1_1entity__builder.html#ab6050fb9a45b5bcbe5e38bdc9964d7e6", null ],
      [ "observe", "structflecs_1_1entity__builder.html#a49e77241334232d5acb67fd92a40f6fc", null ],
      [ "observe", "structflecs_1_1entity__builder.html#a19adebc4c18a744e1258996ac333421e", null ],
      [ "observer", "structflecs_1_1world.html#a876541023d75a8d2aef6206f61581a1e", null ],
      [ "observer", "structflecs_1_1world.html#gab79584a6a6a97e6027511c3966d4187c", null ],
      [ "pair", "structflecs_1_1world.html#aa106734ba4c35baf4cbcb83aeb56591d", null ],
      [ "pair", "structflecs_1_1world.html#a01d0ae38e523fbae689cb6e47ff210cf", null ],
      [ "pair", "structflecs_1_1world.html#ae3ecd53823b33c8d633ab60f65381e4f", null ],
      [ "pipeline", "structflecs_1_1world.html#ga7b2a5cf41e12b0ebafb1633be74aa11d", null ],
      [ "pipeline", "structflecs_1_1world.html#a6c0b631ecdd858fb1e5fd44653e554f6", null ],
      [ "prefab", "structflecs_1_1world.html#gac85030c68a4f438218d42b9ec3a2b450", null ],
      [ "prefab", "structflecs_1_1world.html#gaf2175c4b55288f38daa081c2d6b95ec4", null ],
      [ "primitive", "structflecs_1_1world.html#a108fe405178ca7e719d70fdea54ff9c7", null ],
      [ "progress", "structflecs_1_1world.html#af292376679173c4f14e25947ce7eaa45", null ],
      [ "quantity", "group__cpp__addons__meta.html#gac86161629bc421f597655579e8694b04", null ],
      [ "quantity", "group__cpp__addons__meta.html#ga4b3d8d87501d602f2911da0f0b473536", null ],
      [ "quantity", "group__cpp__addons__meta.html#ga0b531f451234e48028d84593a4a22a9f", null ],
      [ "query", "structflecs_1_1world.html#ga3ba22415d130b509e5eeac5e1f0a6c93", null ],
      [ "query", "structflecs_1_1world.html#ac8a5e864dc1d1333ed4606af25669283", null ],
      [ "query_builder", "structflecs_1_1world.html#a2ba641e98767c10cccb5cf18b359d67c", null ],
      [ "range", "group__cpp__addons__meta.html#gac38baa85a49b23f624cbb8490ed32503", null ],
      [ "rate", "structflecs_1_1system.html#a92b0d661481579937243d5f7a0cf8e76", null ],
      [ "reset_clock", "structflecs_1_1world.html#a5020de2fd47fd317994f6ad03942ebb6", null ],
      [ "run_pipeline", "structflecs_1_1world.html#a4ecb7042ef20c04fa0b5fcec359b683b", null ],
      [ "run_pipeline", "structflecs_1_1world.html#aa04b0b41c98d2d6ca0b0a1a3c2564b95", null ],
      [ "set_doc_brief", "structflecs_1_1entity__builder.html#ga8f84eea617a139d8a7a6cc52039d4078", null ],
      [ "set_doc_color", "structflecs_1_1entity__builder.html#ga9cd9ef24259a552322746a84bbbb9a3c", null ],
      [ "set_doc_detail", "structflecs_1_1entity__builder.html#gaffb31d7837dfc1c4dc3bae89659968d7", null ],
      [ "set_doc_link", "structflecs_1_1entity__builder.html#ga9898033ab60172b2ed5b675b99b96426", null ],
      [ "set_doc_name", "structflecs_1_1entity__builder.html#ga5820cd2803f99cc6ef41e1e5c0eec6a8", null ],
      [ "set_doc_uuid", "structflecs_1_1entity__builder.html#ga1f1be3c70cc2b1174a843ab35da5cf66", null ],
      [ "set_json", "structflecs_1_1entity__builder.html#gaf8f9794d1cca94722dbc8af8c2f97679", null ],
      [ "set_json", "structflecs_1_1entity__builder.html#gae0dd6a23eb80e47ce2c17b24e9a01692", null ],
      [ "set_json", "structflecs_1_1entity__builder.html#ga80c1e161a667c02603ce7bd226fa7019", null ],
      [ "set_json", "structflecs_1_1entity__builder.html#gafbf781155476437fcf38d37e2380f8a8", null ],
      [ "set_json", "structflecs_1_1entity__builder.html#gad6b8a4ab52df0cfbff91cf1a96896218", null ],
      [ "set_json_second", "structflecs_1_1entity__builder.html#ga4c4de9b34edbf7fb3ef8dd1e56601a8c", null ],
      [ "set_pipeline", "structflecs_1_1world.html#a6be3c89e1b069e75491a86bfce303880", null ],
      [ "set_pipeline", "structflecs_1_1world.html#af4bc8b47e9a41441f12825b0778161e8", null ],
      [ "set_target_fps", "structflecs_1_1world.html#a1c67ad5c046c9b898b0cfe1ce3a4e5ad", null ],
      [ "set_task_threads", "structflecs_1_1world.html#a8ef01e622356d5fc8f6a9ddef4f98672", null ],
      [ "set_threads", "structflecs_1_1world.html#a5e85af2ac1ea9b375c74bf9b94b2cd9b", null ],
      [ "set_tick_source", "structflecs_1_1system.html#a8f1ef9547c83c1733bde900a3b8b5b00", null ],
      [ "set_tick_source", "structflecs_1_1system.html#afacd9721ff3f5ae88a3fcf103a7713cd", null ],
      [ "set_time_scale", "structflecs_1_1world.html#a8b974ef50065a20e4484d3c1d886e9c5", null ],
      [ "start", "structflecs_1_1system.html#a60de64d75454385b23995437f1d72669", null ],
      [ "stop", "structflecs_1_1system.html#a8c528baf37154d347366083f0f816846", null ],
      [ "strip_generation", "world_8hpp.html#a339a34f50310d7a3f7d0f3e6372a89bd", null ],
      [ "system", "structflecs_1_1world.html#a111f6b0e868528ac6cc4d2259fff1464", null ],
      [ "system", "structflecs_1_1world.html#ga044c2bfc37acb9f970bb896dea58ad8a", null ],
      [ "term", "structflecs_1_1world.html#a678e5634ddb790fae997b540f033a226", null ],
      [ "term", "structflecs_1_1world.html#ad006cb298624eb92c1135afa99376997", null ],
      [ "term", "structflecs_1_1world.html#gae10e0f557ad931415741ad2f9ae533e6", null ],
      [ "timeout", "structflecs_1_1system.html#a30bd0179e128c6d037bc901a6c27b31b", null ],
      [ "timeout", "structflecs_1_1system.html#ad9fcdd6a0ff2f52e63f5ca0c9b144543", null ],
      [ "timer", "structflecs_1_1world.html#ga47a86ed87cf7c9a384ffd3859623ea08", null ],
      [ "to_constant", "structflecs_1_1entity__view.html#ga58a06a1f245b3b96165092ca16737df1", null ],
      [ "to_entity", "structflecs_1_1world.html#gadae014c4a68b2f6ec1965ab944ae7932", null ],
      [ "to_json", "structflecs_1_1entity__view.html#ga30ca7153aeaa3eb012f44d8aa3374e89", null ],
      [ "to_json", "group__cpp__addons__json.html#ga6409d9ef8b8dd7b365ae41b3a96b416c", null ],
      [ "to_json", "structflecs_1_1query__base.html#ga6409d9ef8b8dd7b365ae41b3a96b416c", null ],
      [ "to_json", "structflecs_1_1world.html#gae2dafcc1231b5f0015e0b991e40c48a8", null ],
      [ "to_json", "structflecs_1_1world.html#ga942011b9de4fcaee6adca58425a21691", null ],
      [ "to_json", "structflecs_1_1world.html#gafe54e0baa3164c35dbc20cabaee28aad", null ],
      [ "unit", "group__cpp__addons__meta.html#ga2bc94f1781c3f53ee9191cf26da588ae", null ],
      [ "unit", "group__cpp__addons__meta.html#ga5876427fe4e3cd6077cd03819d7758e7", null ],
      [ "unit_prefix", "group__cpp__addons__meta.html#ga72b3a9713d33456ff9ee3964f1122ec9", null ],
      [ "using_task_threads", "structflecs_1_1world.html#af784903e7c13885baa3641cdb73c08a0", null ],
      [ "vector", "structflecs_1_1world.html#ad6fa0ad6b1280dec47aaa3ae05beda40", null ],
      [ "vector", "structflecs_1_1world.html#a75a9f2aece32230bfcf142248c81208a", null ],
      [ "warning_range", "group__cpp__addons__meta.html#ga57aba8f77bdfb15b7dbcc910d2a74701", null ]
    ] ]
];